==> snortsms-0.14.9.tbz: www/snortsms/events/fbx_Settings.php <==
<?php
/*
<fusedoc fuse="fbx_Settings.php">
	<responsibilities>
		I set up the enviroment settings for this circuit. If this settings file is being inherited, then you can set a variable outright to override a value set in a parent circuit or use if(!isset(...)) to accept a value set by a parent circuit
	</responsibilities>	
</fusedoc>
*/

//In case no fuseaction was given, I'll set up one to use by default.
if(!isset($attributes["fuseaction"])){ $attributes["fuseaction"] = "home.main"; }

//useful constants
if(!isset($GLOBALS["self"])){ $GLOBALS["self"] = "index.php"; }
$XFA = array();

//default values for layout files
$Fusebox["layoutDir"] = "";
$Fusebox["layoutFile"] = "fbx_DefaultLayout.php";

//should fusebox silently suppress its own error messages? default is FALSE
$Fusebox["suppressErrors"] = false;

if($Fusebox["isHomeCircuit"]) {
//put settings here that you want to execute only when this is the application's home circuit (for example: session_start(); )

} else {
//put settings here that you want to execute only when this is not an application's home circuit

}

//Put settings out here that should run regardless of whether this is the home app or not



/********************************************
********* Database: The PEAR way ************
********************************************/
/*** Include PEAR DB wrapper functions ***/
require_once( "DB.php" );

/*** Open Persistant Database Conection ***/
$GBL["dbdsn_snort"] = $GBL["dbtype_snort"] . "://" . $GBL["dbuser_snort"] . ":" . $GBL["dbpasswd_snort"] . "@" . $GBL["dbhost_snort"] . "/" . $GBL["dbname_snort"];
$db_sa = DB::connect($GBL["dbdsn_snort"],true);
if (DB::isError($db_sa))
	{
	$error = $db_sa->getMessage();
	?>
	<CENTER>
	<BR>
	<table bgcolor="Red"><tr><td>
	<table bgcolor ="White">
	<tr><td>
	<h3 style="color:Red;">Error: Cannot connect to the Snort Alert database.</h3>
	<P><B>Please verify the DB <i>name, type, IP, UserID, and Password</i> are correct in <a href="index.php?fuseaction=conf.main">'Global Setting'</a> menu, and that the database exists.</B></P>
	<P>Error code: <?=$error?></P>
	</td></tr>
	</table>
	</td></tr></table>
	</CENTER>
	<?
	LogEvent("Error: cannot connect to Snort Alert database: $error");
	exit(1);
	}












	
?>

==> snortsms-1.0.0.tbz: www/snortsms/events/fbx_Settings.php <==
<?php
/*
<fusedoc fuse="fbx_Settings.php">
	<responsibilities>
		I set up the enviroment settings for this circuit. If this settings file is being inherited, then you can set a variable outright to override a value set in a parent circuit or use if(!isset(...)) to accept a value set by a parent circuit
	</responsibilities>	
</fusedoc>
*/

//In case no fuseaction was given, I'll set up one to use by default.
if(!isset($attributes["fuseaction"])){ $attributes["fuseaction"] = "home.main"; }

//useful constants
if(!isset($GLOBALS["self"])){ $GLOBALS["self"] = "index.php"; }
$XFA = array();

//default values for layout files
$Fusebox["layoutDir"] = "";
$Fusebox["layoutFile"] = "fbx_DefaultLayout.php";

//should fusebox silently suppress its own error messages? default is FALSE
$Fusebox["suppressErrors"] = false;

if($Fusebox["isHomeCircuit"]) {
//put settings here that you want to execute only when this is the application's home circuit (for example: session_start(); )

} else {
//put settings here that you want to execute only when this is not an application's home circuit

}

//Put settings out here that should run regardless of whether this is the home app or not



/********************************************
********* Database: The PEAR way ************
********************************************/
/*** Include PEAR DB wrapper functions ***/
include_once( "DB.php" );

/*** Open Persistant Database Conection ***/
$GBL["dbdsn_snort"] = $GBL["dbtype_snort"] . "://" . $GBL["dbuser_snort"] . ":" . $GBL["dbpasswd_snort"] . "@" . $GBL["dbhost_snort"] . "/" . $GBL["dbname_snort"];
$db_sa = DB::connect($GBL["dbdsn_snort"],true);
if (DB::isError($db_sa))
	{
	$error = $db_sa->getMessage();
	?>
	<CENTER>
	<BR>
	<table bgcolor="Red"><tr><td>
	<table bgcolor ="White">
	<tr><td>
	<h3 style="color:Red;">Error: Cannot connect to the Snort Alert database.</h3>
	<P><B>Please verify the DB <i>name, type, IP, UserID, and Password</i> are correct in <a href="index.php?fuseaction=conf.main">'Global Setting'</a> menu, and that the database exists.</B></P>
	<P>Error code: <?=$error?></P>
	</td></tr>
	</table>
	</td></tr></table>
	</CENTER>
	<?
	LogEvent("Error: cannot connect to Snort Alert database: $error");
	exit(1);
	}












	
?>
